from chope.element import Element


class a(Element):
    pass


class abbr(Element):
    pass


class acronym(Element):
    pass


class address(Element):
    pass


class applet(Element):
    pass


class area(Element):
    pass


class article(Element):
    pass


class aside(Element):
    pass


class audio(Element):
    pass


class b(Element):
    pass


class base(Element):
    pass


class basefont(Element):
    pass


class bdi(Element):
    pass


class bdo(Element):
    pass


class big(Element):
    pass


class blockquote(Element):
    pass


class body(Element):
    pass


class br(Element):
    pass


class button(Element):
    pass


class canvas(Element):
    pass


class caption(Element):
    pass


class center(Element):
    pass


class cite(Element):
    pass


class code(Element):
    pass


class col(Element):
    pass


class colgroup(Element):
    pass


class data(Element):
    pass


class datalist(Element):
    pass


class dd(Element):
    pass


class details(Element):
    pass


class dfn(Element):
    pass


class dialog(Element):
    pass


class dir(Element):
    pass


class div(Element):
    pass


class dl(Element):
    pass


class dt(Element):
    pass


class em(Element):
    pass


class embed(Element):
    pass


class fieldset(Element):
    pass


class figcaption(Element):
    pass


class figure(Element):
    pass


class font(Element):
    pass


class footer(Element):
    pass


class form(Element):
    pass


class frame(Element):
    pass


class frameset(Element):
    pass


class h1(Element):
    pass


class h2(Element):
    pass


class h3(Element):
    pass


class h4(Element):
    pass


class h5(Element):
    pass


class h6(Element):
    pass


class head(Element):
    pass


class header(Element):
    pass


class hr(Element):
    pass


class html(Element):
    pass


class i(Element):
    pass


class iframe(Element):
    pass


class img(Element):
    pass


class input(Element):
    pass


class ins(Element):
    pass


class kbd(Element):
    pass


class label(Element):
    pass


class legend(Element):
    pass


class li(Element):
    pass


class link(Element):
    pass


class main(Element):
    pass


class map(Element):
    pass


class mark(Element):
    pass


class meta(Element):
    pass


class meter(Element):
    pass


class nav(Element):
    pass


class noframes(Element):
    pass


class noscript(Element):
    pass


class object(Element):
    pass


class ol(Element):
    pass


class optgroup(Element):
    pass


class option(Element):
    pass


class output(Element):
    pass


class p(Element):
    pass


class param(Element):
    pass


class picture(Element):
    pass


class pre(Element):
    pass


class progress(Element):
    pass


class q(Element):
    pass


class rp(Element):
    pass


class rt(Element):
    pass


class ruby(Element):
    pass


class s(Element):
    pass


class samp(Element):
    pass


class script(Element):
    pass


class section(Element):
    pass


class select(Element):
    pass


class small(Element):
    pass


class source(Element):
    pass


class span(Element):
    pass


class strike(Element):
    pass


class strong(Element):
    pass


class style(Element):
    pass


class sub(Element):
    pass


class summary(Element):
    pass


class sup(Element):
    pass


class svg(Element):
    pass


class table(Element):
    pass


class tbody(Element):
    pass


class td(Element):
    pass


class template(Element):
    pass


class textarea(Element):
    pass


class tfoot(Element):
    pass


class th(Element):
    pass


class thead(Element):
    pass


class time(Element):
    pass


class title(Element):
    pass


class tr(Element):
    pass


class track(Element):
    pass


class tt(Element):
    pass


class u(Element):
    pass


class ul(Element):
    pass


class var(Element):
    pass


class video(Element):
    pass


class wbr(Element):
    pass
